UsbDevice class
Represents a USB device discovered on the system.
This model contains basic identifying information about a device, including vendor/product IDs and the number of available configurations.
Constructors
Properties
- configurationCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- productId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vendorId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this UsbDevice into a map representation.
-
toString(
) → String -
Returns a string representation of the device.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited